# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_data_provider/data_provider_template.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='th2_grpc_data_provider/data_provider_template.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\"com.exactpro.th2.dataprovider.grpcP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3th2_grpc_data_provider/data_provider_template.proto\x1a\x1cth2_grpc_common/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xe4\x02\n\tEventData\x12\x1a\n\x08\x65vent_id\x18\x01 \x01(\x0b\x32\x08.EventID\x12!\n\x0fparent_event_id\x18\x02 \x01(\x0b\x32\x08.EventID\x12\x1a\n\x08\x62\x61tch_id\x18\x03 \x01(\x0b\x32\x08.EventID\x12\x12\n\nis_batched\x18\x04 \x01(\x08\x12\x33\n\x0fstart_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\nsuccessful\x18\x07 \x01(\x0e\x32\x0c.EventStatus\x12\x12\n\nevent_name\x18\x08 \x01(\t\x12\x12\n\nevent_type\x18\t \x01(\t\x12\x0c\n\x04\x62ody\x18\n \x01(\x0c\x12(\n\x14\x61ttached_message_ids\x18\x0b \x03(\x0b\x32\n.MessageID\"\xcd\x01\n\rEventMetadata\x12\x1a\n\x08\x65vent_id\x18\x01 \x01(\x0b\x32\x08.EventID\x12!\n\x0fparent_event_id\x18\x02 \x01(\x0b\x32\x08.EventID\x12\x33\n\x0fstart_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\nsuccessful\x18\x05 \x01(\x0e\x32\x0c.EventStatus\x12\x12\n\nevent_name\x18\x06 \x01(\t\x12\x12\n\nevent_type\x18\x07 \x01(\t\"\xd7\x01\n\x0bMessageData\x12\x1e\n\nmessage_id\x18\x01 \x01(\x0b\x32\n.MessageID\x12!\n\nsession_id\x18\x02 \x01(\x0b\x32\r.ConnectionID\x12\x1d\n\tdirection\x18\x03 \x01(\x0e\x32\n.Direction\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cmessage_type\x18\x05 \x01(\t\x12\x0c\n\x04\x62ody\x18\x06 \x01(\t\x12\x13\n\x0b\x62ody_base64\x18\x07 \x01(\t\"S\n\x15LastScannedObjectInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x10timestamp_millis\x18\x02 \x01(\x03\x12\x14\n\x0cscan_counter\x18\x03 \x01(\x03\"!\n\nStringList\x12\x13\n\x0blist_string\x18\x01 \x03(\t\"\x1f\n\tIsMatched\x12\x12\n\nis_matched\x18\x01 \x01(\x08\"!\n\nFilterName\x12\x13\n\x0b\x66ilter_name\x18\x01 \x01(\t\"3\n\x0eListFilterName\x12!\n\x0c\x66ilter_names\x18\x01 \x03(\x0b\x32\x0b.FilterName\"x\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x04type\x18\x02 \x01(\x0e\x32\x14.FilterParameterType\x12+\n\rdefault_value\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04hint\x18\x04 \x01(\t\"U\n\nFilterInfo\x12\x19\n\x04name\x18\x01 \x01(\x0b\x32\x0b.FilterName\x12\x0c\n\x04hint\x18\x02 \x01(\t\x12\x1e\n\nparameters\x18\x03 \x03(\x0b\x32\n.Parameter\"\x8f\x01\n\x06\x46ilter\x12\x19\n\x04name\x18\x01 \x01(\x0b\x32\x0b.FilterName\x12,\n\x08negative\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x0e\n\x06values\x18\x03 \x03(\t\x12,\n\x08\x63onjunct\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"U\n\x06Stream\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x1d\n\tdirection\x18\x02 \x01(\x0e\x32\n.Direction\x12\x1b\n\x07last_id\x18\x03 \x01(\x0b\x32\n.MessageID\"\'\n\x0bStreamsInfo\x12\x18\n\x07streams\x18\x01 \x03(\x0b\x32\x07.Stream\"n\n\x0cMatchRequest\x12\x1c\n\x08\x65vent_id\x18\x01 \x01(\x0b\x32\x08.EventIDH\x00\x12 \n\nmessage_id\x18\x02 \x01(\x0b\x32\n.MessageIDH\x00\x12\x18\n\x07\x66ilters\x18\x03 \x03(\x0b\x32\x07.FilterB\x04\n\x02id\"\x8a\x04\n\x12\x45ventSearchRequest\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x0cparent_event\x18\x03 \x01(\x0b\x32\x08.EventID\x12\'\n\x10search_direction\x18\x04 \x01(\x0e\x32\r.TimeRelation\x12 \n\x0eresume_from_id\x18\x05 \x01(\x0b\x32\x08.EventID\x12\x37\n\x12result_count_limit\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\tkeep_open\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x10limit_for_parent\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\rmetadata_only\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11\x61ttached_messages\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x18\n\x07\x66ilters\x18\x0b \x03(\x0b\x32\x07.Filter\"\x8a\x03\n\x14MessageSearchRequest\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x0eresume_from_id\x18\x03 \x01(\x0b\x32\n.MessageID\x12\'\n\x10search_direction\x18\x04 \x01(\x0e\x32\r.TimeRelation\x12\x37\n\x12result_count_limit\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x1b\n\x06stream\x18\x06 \x01(\x0b\x32\x0b.StringList\x12-\n\tkeep_open\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1e\n\nmessage_id\x18\x08 \x03(\x0b\x32\n.MessageID\x12\x18\n\x07\x66ilters\x18\t \x03(\x0b\x32\x07.Filter\"\xdc\x01\n\x0eStreamResponse\x12\x1b\n\x05\x65vent\x18\x01 \x01(\x0b\x32\n.EventDataH\x00\x12\x1f\n\x07message\x18\x02 \x01(\x0b\x32\x0c.MessageDataH\x00\x12(\n\x0e\x65vent_metadata\x18\x03 \x01(\x0b\x32\x0e.EventMetadataH\x00\x12\x35\n\x13last_scanned_object\x18\x04 \x01(\x0b\x32\x16.LastScannedObjectInfoH\x00\x12#\n\x0bstream_info\x18\x05 \x01(\x0b\x32\x0c.StreamsInfoH\x00\x42\x06\n\x04\x64\x61ta*K\n\x13\x46ilterParameterType\x12\n\n\x06NUMBER\x10\x00\x12\x0b\n\x07\x42OOLEAN\x10\x01\x12\n\n\x06STRING\x10\x02\x12\x0f\n\x0bSTRING_LIST\x10\x03*&\n\x0cTimeRelation\x12\x08\n\x04NEXT\x10\x00\x12\x0c\n\x08PREVIOUS\x10\x01\x32\xce\x04\n\x0c\x44\x61taProvider\x12\"\n\x08getEvent\x12\x08.EventID\x1a\n.EventData\"\x00\x12(\n\ngetMessage\x12\n.MessageID\x1a\x0c.MessageData\"\x00\x12:\n\x11getMessageStreams\x12\x16.google.protobuf.Empty\x1a\x0b.StringList\"\x00\x12<\n\x0esearchMessages\x12\x15.MessageSearchRequest\x1a\x0f.StreamResponse\"\x00\x30\x01\x12\x38\n\x0csearchEvents\x12\x13.EventSearchRequest\x1a\x0f.StreamResponse\"\x00\x30\x01\x12?\n\x12getMessagesFilters\x12\x16.google.protobuf.Empty\x1a\x0f.ListFilterName\"\x00\x12=\n\x10getEventsFilters\x12\x16.google.protobuf.Empty\x1a\x0f.ListFilterName\"\x00\x12\x30\n\x12getEventFilterInfo\x12\x0b.FilterName\x1a\x0b.FilterInfo\"\x00\x12\x32\n\x14getMessageFilterInfo\x12\x0b.FilterName\x1a\x0b.FilterInfo\"\x00\x12)\n\nmatchEvent\x12\r.MatchRequest\x1a\n.IsMatched\"\x00\x12+\n\x0cmatchMessage\x12\r.MatchRequest\x1a\n.IsMatched\"\x00\x42&\n\"com.exactpro.th2.dataprovider.grpcP\x01\x62\x06proto3'
  ,
  dependencies=[th2__grpc__common_dot_common__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])

_FILTERPARAMETERTYPE = _descriptor.EnumDescriptor(
  name='FilterParameterType',
  full_name='FilterParameterType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING_LIST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2972,
  serialized_end=3047,
)
_sym_db.RegisterEnumDescriptor(_FILTERPARAMETERTYPE)

FilterParameterType = enum_type_wrapper.EnumTypeWrapper(_FILTERPARAMETERTYPE)
_TIMERELATION = _descriptor.EnumDescriptor(
  name='TimeRelation',
  full_name='TimeRelation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEXT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREVIOUS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3049,
  serialized_end=3087,
)
_sym_db.RegisterEnumDescriptor(_TIMERELATION)

TimeRelation = enum_type_wrapper.EnumTypeWrapper(_TIMERELATION)
NUMBER = 0
BOOLEAN = 1
STRING = 2
STRING_LIST = 3
NEXT = 0
PREVIOUS = 1



_EVENTDATA = _descriptor.Descriptor(
  name='EventData',
  full_name='EventData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='EventData.event_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='EventData.parent_event_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_id', full_name='EventData.batch_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_batched', full_name='EventData.is_batched', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='EventData.start_timestamp', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='EventData.end_timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='successful', full_name='EventData.successful', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_name', full_name='EventData.event_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='EventData.event_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='EventData.body', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_message_ids', full_name='EventData.attached_message_ids', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=207,
  serialized_end=563,
)


_EVENTMETADATA = _descriptor.Descriptor(
  name='EventMetadata',
  full_name='EventMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='EventMetadata.event_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='EventMetadata.parent_event_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='EventMetadata.start_timestamp', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='successful', full_name='EventMetadata.successful', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_name', full_name='EventMetadata.event_name', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='EventMetadata.event_type', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=771,
)


_MESSAGEDATA = _descriptor.Descriptor(
  name='MessageData',
  full_name='MessageData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='MessageData.message_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='MessageData.session_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='MessageData.direction', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='MessageData.timestamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='MessageData.message_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='MessageData.body', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body_base64', full_name='MessageData.body_base64', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=989,
)


_LASTSCANNEDOBJECTINFO = _descriptor.Descriptor(
  name='LastScannedObjectInfo',
  full_name='LastScannedObjectInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='LastScannedObjectInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_millis', full_name='LastScannedObjectInfo.timestamp_millis', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scan_counter', full_name='LastScannedObjectInfo.scan_counter', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=991,
  serialized_end=1074,
)


_STRINGLIST = _descriptor.Descriptor(
  name='StringList',
  full_name='StringList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_string', full_name='StringList.list_string', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1076,
  serialized_end=1109,
)


_ISMATCHED = _descriptor.Descriptor(
  name='IsMatched',
  full_name='IsMatched',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_matched', full_name='IsMatched.is_matched', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1142,
)


_FILTERNAME = _descriptor.Descriptor(
  name='FilterName',
  full_name='FilterName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter_name', full_name='FilterName.filter_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1177,
)


_LISTFILTERNAME = _descriptor.Descriptor(
  name='ListFilterName',
  full_name='ListFilterName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter_names', full_name='ListFilterName.filter_names', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1179,
  serialized_end=1230,
)


_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Parameter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Parameter.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='Parameter.default_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hint', full_name='Parameter.hint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1232,
  serialized_end=1352,
)


_FILTERINFO = _descriptor.Descriptor(
  name='FilterInfo',
  full_name='FilterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='FilterInfo.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hint', full_name='FilterInfo.hint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='FilterInfo.parameters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1354,
  serialized_end=1439,
)


_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Filter.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative', full_name='Filter.negative', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='Filter.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conjunct', full_name='Filter.conjunct', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1442,
  serialized_end=1585,
)


_STREAM = _descriptor.Descriptor(
  name='Stream',
  full_name='Stream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='Stream.session', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='Stream.direction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_id', full_name='Stream.last_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1587,
  serialized_end=1672,
)


_STREAMSINFO = _descriptor.Descriptor(
  name='StreamsInfo',
  full_name='StreamsInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='streams', full_name='StreamsInfo.streams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1674,
  serialized_end=1713,
)


_MATCHREQUEST = _descriptor.Descriptor(
  name='MatchRequest',
  full_name='MatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_id', full_name='MatchRequest.event_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='MatchRequest.message_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='MatchRequest.filters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='MatchRequest.id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1715,
  serialized_end=1825,
)


_EVENTSEARCHREQUEST = _descriptor.Descriptor(
  name='EventSearchRequest',
  full_name='EventSearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='EventSearchRequest.start_timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='EventSearchRequest.end_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_event', full_name='EventSearchRequest.parent_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_direction', full_name='EventSearchRequest.search_direction', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resume_from_id', full_name='EventSearchRequest.resume_from_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_count_limit', full_name='EventSearchRequest.result_count_limit', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_open', full_name='EventSearchRequest.keep_open', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_for_parent', full_name='EventSearchRequest.limit_for_parent', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_only', full_name='EventSearchRequest.metadata_only', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_messages', full_name='EventSearchRequest.attached_messages', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='EventSearchRequest.filters', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1828,
  serialized_end=2350,
)


_MESSAGESEARCHREQUEST = _descriptor.Descriptor(
  name='MessageSearchRequest',
  full_name='MessageSearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='MessageSearchRequest.start_timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='MessageSearchRequest.end_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resume_from_id', full_name='MessageSearchRequest.resume_from_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='search_direction', full_name='MessageSearchRequest.search_direction', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_count_limit', full_name='MessageSearchRequest.result_count_limit', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='MessageSearchRequest.stream', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_open', full_name='MessageSearchRequest.keep_open', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='MessageSearchRequest.message_id', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='MessageSearchRequest.filters', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2353,
  serialized_end=2747,
)


_STREAMRESPONSE = _descriptor.Descriptor(
  name='StreamResponse',
  full_name='StreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='StreamResponse.event', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='StreamResponse.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_metadata', full_name='StreamResponse.event_metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_scanned_object', full_name='StreamResponse.last_scanned_object', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_info', full_name='StreamResponse.stream_info', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='StreamResponse.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2750,
  serialized_end=2970,
)

_EVENTDATA.fields_by_name['event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTDATA.fields_by_name['parent_event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTDATA.fields_by_name['batch_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTDATA.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTDATA.fields_by_name['end_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTDATA.fields_by_name['successful'].enum_type = th2__grpc__common_dot_common__pb2._EVENTSTATUS
_EVENTDATA.fields_by_name['attached_message_ids'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_EVENTMETADATA.fields_by_name['event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTMETADATA.fields_by_name['parent_event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTMETADATA.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTMETADATA.fields_by_name['successful'].enum_type = th2__grpc__common_dot_common__pb2._EVENTSTATUS
_MESSAGEDATA.fields_by_name['message_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_MESSAGEDATA.fields_by_name['session_id'].message_type = th2__grpc__common_dot_common__pb2._CONNECTIONID
_MESSAGEDATA.fields_by_name['direction'].enum_type = th2__grpc__common_dot_common__pb2._DIRECTION
_MESSAGEDATA.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTFILTERNAME.fields_by_name['filter_names'].message_type = _FILTERNAME
_PARAMETER.fields_by_name['type'].enum_type = _FILTERPARAMETERTYPE
_PARAMETER.fields_by_name['default_value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_FILTERINFO.fields_by_name['name'].message_type = _FILTERNAME
_FILTERINFO.fields_by_name['parameters'].message_type = _PARAMETER
_FILTER.fields_by_name['name'].message_type = _FILTERNAME
_FILTER.fields_by_name['negative'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FILTER.fields_by_name['conjunct'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_STREAM.fields_by_name['direction'].enum_type = th2__grpc__common_dot_common__pb2._DIRECTION
_STREAM.fields_by_name['last_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_STREAMSINFO.fields_by_name['streams'].message_type = _STREAM
_MATCHREQUEST.fields_by_name['event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_MATCHREQUEST.fields_by_name['message_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_MATCHREQUEST.fields_by_name['filters'].message_type = _FILTER
_MATCHREQUEST.oneofs_by_name['id'].fields.append(
  _MATCHREQUEST.fields_by_name['event_id'])
_MATCHREQUEST.fields_by_name['event_id'].containing_oneof = _MATCHREQUEST.oneofs_by_name['id']
_MATCHREQUEST.oneofs_by_name['id'].fields.append(
  _MATCHREQUEST.fields_by_name['message_id'])
_MATCHREQUEST.fields_by_name['message_id'].containing_oneof = _MATCHREQUEST.oneofs_by_name['id']
_EVENTSEARCHREQUEST.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTSEARCHREQUEST.fields_by_name['end_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENTSEARCHREQUEST.fields_by_name['parent_event'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTSEARCHREQUEST.fields_by_name['search_direction'].enum_type = _TIMERELATION
_EVENTSEARCHREQUEST.fields_by_name['resume_from_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_EVENTSEARCHREQUEST.fields_by_name['result_count_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_EVENTSEARCHREQUEST.fields_by_name['keep_open'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EVENTSEARCHREQUEST.fields_by_name['limit_for_parent'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_EVENTSEARCHREQUEST.fields_by_name['metadata_only'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EVENTSEARCHREQUEST.fields_by_name['attached_messages'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EVENTSEARCHREQUEST.fields_by_name['filters'].message_type = _FILTER
_MESSAGESEARCHREQUEST.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGESEARCHREQUEST.fields_by_name['end_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGESEARCHREQUEST.fields_by_name['resume_from_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_MESSAGESEARCHREQUEST.fields_by_name['search_direction'].enum_type = _TIMERELATION
_MESSAGESEARCHREQUEST.fields_by_name['result_count_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_MESSAGESEARCHREQUEST.fields_by_name['stream'].message_type = _STRINGLIST
_MESSAGESEARCHREQUEST.fields_by_name['keep_open'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MESSAGESEARCHREQUEST.fields_by_name['message_id'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEID
_MESSAGESEARCHREQUEST.fields_by_name['filters'].message_type = _FILTER
_STREAMRESPONSE.fields_by_name['event'].message_type = _EVENTDATA
_STREAMRESPONSE.fields_by_name['message'].message_type = _MESSAGEDATA
_STREAMRESPONSE.fields_by_name['event_metadata'].message_type = _EVENTMETADATA
_STREAMRESPONSE.fields_by_name['last_scanned_object'].message_type = _LASTSCANNEDOBJECTINFO
_STREAMRESPONSE.fields_by_name['stream_info'].message_type = _STREAMSINFO
_STREAMRESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMRESPONSE.fields_by_name['event'])
_STREAMRESPONSE.fields_by_name['event'].containing_oneof = _STREAMRESPONSE.oneofs_by_name['data']
_STREAMRESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMRESPONSE.fields_by_name['message'])
_STREAMRESPONSE.fields_by_name['message'].containing_oneof = _STREAMRESPONSE.oneofs_by_name['data']
_STREAMRESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMRESPONSE.fields_by_name['event_metadata'])
_STREAMRESPONSE.fields_by_name['event_metadata'].containing_oneof = _STREAMRESPONSE.oneofs_by_name['data']
_STREAMRESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMRESPONSE.fields_by_name['last_scanned_object'])
_STREAMRESPONSE.fields_by_name['last_scanned_object'].containing_oneof = _STREAMRESPONSE.oneofs_by_name['data']
_STREAMRESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMRESPONSE.fields_by_name['stream_info'])
_STREAMRESPONSE.fields_by_name['stream_info'].containing_oneof = _STREAMRESPONSE.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['EventData'] = _EVENTDATA
DESCRIPTOR.message_types_by_name['EventMetadata'] = _EVENTMETADATA
DESCRIPTOR.message_types_by_name['MessageData'] = _MESSAGEDATA
DESCRIPTOR.message_types_by_name['LastScannedObjectInfo'] = _LASTSCANNEDOBJECTINFO
DESCRIPTOR.message_types_by_name['StringList'] = _STRINGLIST
DESCRIPTOR.message_types_by_name['IsMatched'] = _ISMATCHED
DESCRIPTOR.message_types_by_name['FilterName'] = _FILTERNAME
DESCRIPTOR.message_types_by_name['ListFilterName'] = _LISTFILTERNAME
DESCRIPTOR.message_types_by_name['Parameter'] = _PARAMETER
DESCRIPTOR.message_types_by_name['FilterInfo'] = _FILTERINFO
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
DESCRIPTOR.message_types_by_name['Stream'] = _STREAM
DESCRIPTOR.message_types_by_name['StreamsInfo'] = _STREAMSINFO
DESCRIPTOR.message_types_by_name['MatchRequest'] = _MATCHREQUEST
DESCRIPTOR.message_types_by_name['EventSearchRequest'] = _EVENTSEARCHREQUEST
DESCRIPTOR.message_types_by_name['MessageSearchRequest'] = _MESSAGESEARCHREQUEST
DESCRIPTOR.message_types_by_name['StreamResponse'] = _STREAMRESPONSE
DESCRIPTOR.enum_types_by_name['FilterParameterType'] = _FILTERPARAMETERTYPE
DESCRIPTOR.enum_types_by_name['TimeRelation'] = _TIMERELATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventData = _reflection.GeneratedProtocolMessageType('EventData', (_message.Message,), {
  'DESCRIPTOR' : _EVENTDATA,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:EventData)
  })
_sym_db.RegisterMessage(EventData)

EventMetadata = _reflection.GeneratedProtocolMessageType('EventMetadata', (_message.Message,), {
  'DESCRIPTOR' : _EVENTMETADATA,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:EventMetadata)
  })
_sym_db.RegisterMessage(EventMetadata)

MessageData = _reflection.GeneratedProtocolMessageType('MessageData', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEDATA,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:MessageData)
  })
_sym_db.RegisterMessage(MessageData)

LastScannedObjectInfo = _reflection.GeneratedProtocolMessageType('LastScannedObjectInfo', (_message.Message,), {
  'DESCRIPTOR' : _LASTSCANNEDOBJECTINFO,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:LastScannedObjectInfo)
  })
_sym_db.RegisterMessage(LastScannedObjectInfo)

StringList = _reflection.GeneratedProtocolMessageType('StringList', (_message.Message,), {
  'DESCRIPTOR' : _STRINGLIST,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:StringList)
  })
_sym_db.RegisterMessage(StringList)

IsMatched = _reflection.GeneratedProtocolMessageType('IsMatched', (_message.Message,), {
  'DESCRIPTOR' : _ISMATCHED,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:IsMatched)
  })
_sym_db.RegisterMessage(IsMatched)

FilterName = _reflection.GeneratedProtocolMessageType('FilterName', (_message.Message,), {
  'DESCRIPTOR' : _FILTERNAME,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:FilterName)
  })
_sym_db.RegisterMessage(FilterName)

ListFilterName = _reflection.GeneratedProtocolMessageType('ListFilterName', (_message.Message,), {
  'DESCRIPTOR' : _LISTFILTERNAME,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:ListFilterName)
  })
_sym_db.RegisterMessage(ListFilterName)

Parameter = _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETER,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:Parameter)
  })
_sym_db.RegisterMessage(Parameter)

FilterInfo = _reflection.GeneratedProtocolMessageType('FilterInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILTERINFO,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:FilterInfo)
  })
_sym_db.RegisterMessage(FilterInfo)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:Filter)
  })
_sym_db.RegisterMessage(Filter)

Stream = _reflection.GeneratedProtocolMessageType('Stream', (_message.Message,), {
  'DESCRIPTOR' : _STREAM,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:Stream)
  })
_sym_db.RegisterMessage(Stream)

StreamsInfo = _reflection.GeneratedProtocolMessageType('StreamsInfo', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSINFO,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:StreamsInfo)
  })
_sym_db.RegisterMessage(StreamsInfo)

MatchRequest = _reflection.GeneratedProtocolMessageType('MatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _MATCHREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:MatchRequest)
  })
_sym_db.RegisterMessage(MatchRequest)

EventSearchRequest = _reflection.GeneratedProtocolMessageType('EventSearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSEARCHREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:EventSearchRequest)
  })
_sym_db.RegisterMessage(EventSearchRequest)

MessageSearchRequest = _reflection.GeneratedProtocolMessageType('MessageSearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESEARCHREQUEST,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:MessageSearchRequest)
  })
_sym_db.RegisterMessage(MessageSearchRequest)

StreamResponse = _reflection.GeneratedProtocolMessageType('StreamResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMRESPONSE,
  '__module__' : 'th2_grpc_data_provider.data_provider_template_pb2'
  # @@protoc_insertion_point(class_scope:StreamResponse)
  })
_sym_db.RegisterMessage(StreamResponse)


DESCRIPTOR._options = None

_DATAPROVIDER = _descriptor.ServiceDescriptor(
  name='DataProvider',
  full_name='DataProvider',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3090,
  serialized_end=3680,
  methods=[
  _descriptor.MethodDescriptor(
    name='getEvent',
    full_name='DataProvider.getEvent',
    index=0,
    containing_service=None,
    input_type=th2__grpc__common_dot_common__pb2._EVENTID,
    output_type=_EVENTDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getMessage',
    full_name='DataProvider.getMessage',
    index=1,
    containing_service=None,
    input_type=th2__grpc__common_dot_common__pb2._MESSAGEID,
    output_type=_MESSAGEDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getMessageStreams',
    full_name='DataProvider.getMessageStreams',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_STRINGLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='searchMessages',
    full_name='DataProvider.searchMessages',
    index=3,
    containing_service=None,
    input_type=_MESSAGESEARCHREQUEST,
    output_type=_STREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='searchEvents',
    full_name='DataProvider.searchEvents',
    index=4,
    containing_service=None,
    input_type=_EVENTSEARCHREQUEST,
    output_type=_STREAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getMessagesFilters',
    full_name='DataProvider.getMessagesFilters',
    index=5,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTFILTERNAME,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getEventsFilters',
    full_name='DataProvider.getEventsFilters',
    index=6,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTFILTERNAME,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getEventFilterInfo',
    full_name='DataProvider.getEventFilterInfo',
    index=7,
    containing_service=None,
    input_type=_FILTERNAME,
    output_type=_FILTERINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getMessageFilterInfo',
    full_name='DataProvider.getMessageFilterInfo',
    index=8,
    containing_service=None,
    input_type=_FILTERNAME,
    output_type=_FILTERINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='matchEvent',
    full_name='DataProvider.matchEvent',
    index=9,
    containing_service=None,
    input_type=_MATCHREQUEST,
    output_type=_ISMATCHED,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='matchMessage',
    full_name='DataProvider.matchMessage',
    index=10,
    containing_service=None,
    input_type=_MATCHREQUEST,
    output_type=_ISMATCHED,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAPROVIDER)

DESCRIPTOR.services_by_name['DataProvider'] = _DATAPROVIDER

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2
from th2_grpc_data_provider import data_provider_template_pb2 as th2__grpc__data__provider_dot_data__provider__template__pb2


class DataProviderStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getEvent = channel.unary_unary(
                '/DataProvider/getEvent',
                request_serializer=th2__grpc__common_dot_common__pb2.EventID.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.EventData.FromString,
                )
        self.getMessage = channel.unary_unary(
                '/DataProvider/getMessage',
                request_serializer=th2__grpc__common_dot_common__pb2.MessageID.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.MessageData.FromString,
                )
        self.getMessageStreams = channel.unary_unary(
                '/DataProvider/getMessageStreams',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.StringList.FromString,
                )
        self.searchMessages = channel.unary_stream(
                '/DataProvider/searchMessages',
                request_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.MessageSearchRequest.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.StreamResponse.FromString,
                )
        self.searchEvents = channel.unary_stream(
                '/DataProvider/searchEvents',
                request_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.EventSearchRequest.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.StreamResponse.FromString,
                )
        self.getMessagesFilters = channel.unary_unary(
                '/DataProvider/getMessagesFilters',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.ListFilterName.FromString,
                )
        self.getEventsFilters = channel.unary_unary(
                '/DataProvider/getEventsFilters',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.ListFilterName.FromString,
                )
        self.getEventFilterInfo = channel.unary_unary(
                '/DataProvider/getEventFilterInfo',
                request_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.FilterName.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.FilterInfo.FromString,
                )
        self.getMessageFilterInfo = channel.unary_unary(
                '/DataProvider/getMessageFilterInfo',
                request_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.FilterName.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.FilterInfo.FromString,
                )
        self.matchEvent = channel.unary_unary(
                '/DataProvider/matchEvent',
                request_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.MatchRequest.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.IsMatched.FromString,
                )
        self.matchMessage = channel.unary_unary(
                '/DataProvider/matchMessage',
                request_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.MatchRequest.SerializeToString,
                response_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.IsMatched.FromString,
                )


class DataProviderServicer(object):
    """Missing associated documentation comment in .proto file."""

    def getEvent(self, request, context):
        """returns a single event with the specified id 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getMessage(self, request, context):
        """returns a single message with the specified id 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getMessageStreams(self, request, context):
        """returns a list of message stream names 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def searchMessages(self, request, context):
        """Creates a message stream that matches the filter. 

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def searchEvents(self, request, context):
        """Creates an event or an event metadata stream that matches the filter. 

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getMessagesFilters(self, request, context):
        """gets all the names of sse message filters 

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getEventsFilters(self, request, context):
        """gets all the names of sse event filters 

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getEventFilterInfo(self, request, context):
        """gets filter info 

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getMessageFilterInfo(self, request, context):
        """gets filter info 

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def matchEvent(self, request, context):
        """Checks that the event with the specified id is matched by the filter 

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def matchMessage(self, request, context):
        """Checks that the message with the specified id is matched by the filter 

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataProviderServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.getEvent,
                    request_deserializer=th2__grpc__common_dot_common__pb2.EventID.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.EventData.SerializeToString,
            ),
            'getMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.getMessage,
                    request_deserializer=th2__grpc__common_dot_common__pb2.MessageID.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.MessageData.SerializeToString,
            ),
            'getMessageStreams': grpc.unary_unary_rpc_method_handler(
                    servicer.getMessageStreams,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.StringList.SerializeToString,
            ),
            'searchMessages': grpc.unary_stream_rpc_method_handler(
                    servicer.searchMessages,
                    request_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.MessageSearchRequest.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.StreamResponse.SerializeToString,
            ),
            'searchEvents': grpc.unary_stream_rpc_method_handler(
                    servicer.searchEvents,
                    request_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.EventSearchRequest.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.StreamResponse.SerializeToString,
            ),
            'getMessagesFilters': grpc.unary_unary_rpc_method_handler(
                    servicer.getMessagesFilters,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.ListFilterName.SerializeToString,
            ),
            'getEventsFilters': grpc.unary_unary_rpc_method_handler(
                    servicer.getEventsFilters,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.ListFilterName.SerializeToString,
            ),
            'getEventFilterInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getEventFilterInfo,
                    request_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.FilterName.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.FilterInfo.SerializeToString,
            ),
            'getMessageFilterInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getMessageFilterInfo,
                    request_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.FilterName.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.FilterInfo.SerializeToString,
            ),
            'matchEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.matchEvent,
                    request_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.MatchRequest.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.IsMatched.SerializeToString,
            ),
            'matchMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.matchMessage,
                    request_deserializer=th2__grpc__data__provider_dot_data__provider__template__pb2.MatchRequest.FromString,
                    response_serializer=th2__grpc__data__provider_dot_data__provider__template__pb2.IsMatched.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'DataProvider', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataProvider(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def getEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DataProvider/getEvent',
            th2__grpc__common_dot_common__pb2.EventID.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.EventData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DataProvider/getMessage',
            th2__grpc__common_dot_common__pb2.MessageID.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.MessageData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getMessageStreams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DataProvider/getMessageStreams',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.StringList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def searchMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/DataProvider/searchMessages',
            th2__grpc__data__provider_dot_data__provider__template__pb2.MessageSearchRequest.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.StreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def searchEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/DataProvider/searchEvents',
            th2__grpc__data__provider_dot_data__provider__template__pb2.EventSearchRequest.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.StreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getMessagesFilters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DataProvider/getMessagesFilters',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.ListFilterName.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getEventsFilters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DataProvider/getEventsFilters',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.ListFilterName.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getEventFilterInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DataProvider/getEventFilterInfo',
            th2__grpc__data__provider_dot_data__provider__template__pb2.FilterName.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.FilterInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getMessageFilterInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DataProvider/getMessageFilterInfo',
            th2__grpc__data__provider_dot_data__provider__template__pb2.FilterName.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.FilterInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def matchEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DataProvider/matchEvent',
            th2__grpc__data__provider_dot_data__provider__template__pb2.MatchRequest.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.IsMatched.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def matchMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/DataProvider/matchMessage',
            th2__grpc__data__provider_dot_data__provider__template__pb2.MatchRequest.SerializeToString,
            th2__grpc__data__provider_dot_data__provider__template__pb2.IsMatched.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from . import data_provider_template_pb2_grpc as importStub

class DataProviderService(object):

    def __init__(self, router):
        self.connector = router.get_connection(DataProviderService, importStub.DataProviderStub)

    def getEvent(self, request, timeout=None):
        return self.connector.create_request('getEvent', request, timeout)

    def getMessage(self, request, timeout=None):
        return self.connector.create_request('getMessage', request, timeout)

    def getMessageStreams(self, request, timeout=None):
        return self.connector.create_request('getMessageStreams', request, timeout)

    def searchMessages(self, request, timeout=None):
        return self.connector.create_request('searchMessages', request, timeout)

    def searchEvents(self, request, timeout=None):
        return self.connector.create_request('searchEvents', request, timeout)

    def getMessagesFilters(self, request, timeout=None):
        return self.connector.create_request('getMessagesFilters', request, timeout)

    def getEventsFilters(self, request, timeout=None):
        return self.connector.create_request('getEventsFilters', request, timeout)

    def getEventFilterInfo(self, request, timeout=None):
        return self.connector.create_request('getEventFilterInfo', request, timeout)

    def getMessageFilterInfo(self, request, timeout=None):
        return self.connector.create_request('getMessageFilterInfo', request, timeout)

    def matchEvent(self, request, timeout=None):
        return self.connector.create_request('matchEvent', request, timeout)

    def matchMessage(self, request, timeout=None):
        return self.connector.create_request('matchMessage', request, timeout)